@@ -9,8 +9,11 @@ let distrib =
   let exclude_paths () = Ok [".git";".gitignore";".gitattributes";"_build"] in
   Pkg.distrib ~exclude_paths ()
 
+let opams =
+  [Pkg.opam_file "cmdliner.opam"]
+
 let () =
-  Pkg.describe ~distrib "cmdliner" @@ fun c ->
+  Pkg.describe ~distrib "cmdliner" ~opams @@ fun c ->
   Ok [ Pkg.mllib ~api:["Cmdliner"] "src/cmdliner.mllib";
        test "test/chorus";
        test "test/cp_ex";
@@ -26,4 +29,5 @@ let () =
        Pkg.test ~run:false "test/test_pos_left";
        Pkg.test ~run:false "test/test_pos_req";
        Pkg.test ~run:false "test/test_opt_req";
-       Pkg.test ~run:false "test/test_term_dups"; ]
+       Pkg.test ~run:false "test/test_term_dups";
+       Pkg.test ~run:false "test/test_with_used_args"; ]
