@@ -9,7 +9,7 @@ let cp verbose recurse force srcs dest =
     `Error (false, dest ^ " is not a directory")
   else
   `Ok (Printf.printf
-           "verbose = %b\nrecurse = %b\nforce = %b\nsrcs = %s\ndest = %s\n"
+           "verbose = %B\nrecurse = %B\nforce = %B\nsrcs = %s\ndest = %s\n"
            verbose recurse force (String.concat ", " srcs) dest)
 
 (* Command line interface *)
@@ -49,6 +49,6 @@ let cmd =
       `P "Email them to <hehey at example.org>."; ]
   in
   Term.(ret (const cp $ verbose $ recurse $ force $ srcs $ dest)),
-  Term.info "cp" ~version:"v1.0.2" ~doc ~exits ~man ~man_xrefs
+  Term.info "cp" ~version:"v1.0.4" ~doc ~exits ~man ~man_xrefs
 
 let () = Term.(exit @@ eval cmd)
