@@ -2,9 +2,8 @@
 
 let revolt () = print_endline "Revolt!"
 
-open Cmdliner;;
+open Cmdliner
 
 let revolt_t = Term.(const revolt $ const ())
 
-let () = match Term.eval (revolt_t, Term.info "revolt") with
-| `Error _ -> exit 1 | _ -> exit 0
+let () = Term.(exit @@ eval (revolt_t, Term.info "revolt"))
